@@ -188,6 +188,8 @@ setMethod(
 #'              The \code{dbExecute()} method submits a query to Athena and waits for the query to be executed.
 #' @name Query
 #' @inheritParams DBI::dbSendQuery
+#' @param unload boolean input to modify `statement` to align with \href{https://docs.aws.amazon.com/athena/latest/ug/unload.html}{AWS Athena UNLOAD},
+#'              default is set to \code{FALSE}.
 #' @return Returns \code{AthenaResult} s4 class.
 #' @seealso \code{\link[DBI]{dbSendQuery}}, \code{\link[DBI]{dbSendStatement}}, \code{\link[DBI]{dbExecute}}
 #' @examples
@@ -217,11 +219,16 @@ NULL
 setMethod(
   "dbSendQuery", c("AthenaConnection", "character"),
   function(conn,
-           statement = NULL, ...){
+           statement = NULL,
+           unload = FALSE,
+           ...){
     con_error_msg(conn, msg = "Connection already closed.")
-    s3_staging_dir <- conn@info$s3_staging
+    stopifnot(is.logical(unload))
     res <- AthenaResult(
-      conn=conn, statement= statement, s3_staging_dir = s3_staging_dir)
+      conn=conn,
+      statement=statement,
+      s3_staging_dir=conn@info$s3_staging,
+      unload=unload)
     return(res)
 })
 
@@ -230,11 +237,16 @@ setMethod(
 setMethod(
   "dbSendStatement", c("AthenaConnection", "character"),
   function(conn,
-           statement = NULL, ...){
+           statement = NULL,
+           unload = FALSE,
+           ...){
     con_error_msg(conn, msg = "Connection already closed.")
-    s3_staging_dir <- conn@info$s3_staging
+    stopifnot(is.logical(unload))
     res <- AthenaResult(
-      conn =conn, statement= statement, s3_staging_dir = s3_staging_dir)
+      conn=conn,
+      statement=statement,
+      s3_staging_dir=conn@info$s3_staging,
+      unload=unload)
     return(res)
 })
 
@@ -243,11 +255,16 @@ setMethod(
 setMethod(
   "dbExecute", c("AthenaConnection", "character"),
   function(conn,
-           statement = NULL, ...){
+           statement = NULL,
+           unload = FALSE,
+           ...){
     con_error_msg(conn, msg = "Connection already closed.")
-    s3_staging_dir <- conn@info$s3_staging
+    stopifnot(is.logical(unload))
     res <- AthenaResult(
-      conn=conn, statement= statement, s3_staging_dir = s3_staging_dir)
+      conn=conn,
+      statement=statement,
+      s3_staging_dir=conn@info$s3_staging,
+      unload=unload)
     poll(res)
     
     # if query failed stop
@@ -398,7 +415,7 @@ setMethod(
 #' \dontrun{
 #' # Note: 
 #' # - Require AWS Account to run below example.
-#' # - Different connection methods can be used please see `noctua::dbConnect` documnentation
+#' # - Different connection methods can be used please see `RAthena::dbConnect` documnentation
 #' 
 #' library(DBI)
 #' library(RAthena)
@@ -599,11 +616,11 @@ setMethod(
         error = function(e) py_error(e))
       # Detect if key ends with "/" or if it has ".": https://github.com/DyfanJones/noctua/issues/125
       if(!grepl("\\.|/$", s3_path$key))
-        s3_path$key <- sprintf("%s/", s3_path$key)
+        s3_path[["key"]] <- sprintf("%s/", s3_path[["key"]])
       all_keys <- list()
       # Get all s3 objects linked to table
-      kwargs <- list(Bucket=s3_path$bucket, Prefix=s3_path$key)
-      while(is.null(kwargs$ContinuationToken)) {
+      kwargs <- list(Bucket=s3_path[["bucket"]], Prefix=s3_path[["key"]])
+      while(is.null(kwargs[["ContinuationToken"]])) {
         objects <- do.call(conn@ptr$S3$list_objects_v2, kwargs)
         all_keys <- c(all_keys, lapply(objects$Contents, function(x) list(Key=x$Key)))
         if(identical(objects$NextContinuationToken, kwargs$ContinuationToken) || length(objects$NextContinuationToken) == 0) break
@@ -625,7 +642,7 @@ setMethod(
         for(i in seq_along(key_parts))
           conn@ptr$S3$delete_objects(Bucket = s3_path$bucket, Delete = list(Objects = key_parts[[i]]))
       } else {
-        warning(sprintf('Failed to remove AWS S3 files from: "s3://%s/%s/". Please check if AWS S3 files exist.',
+        warning(sprintf('Failed to remove AWS S3 files from: "s3://%s/%s". Please check if AWS S3 files exist.',
                         s3_path$bucket, s3_path$key), call. = F)
       }
     }
@@ -646,6 +663,8 @@ setMethod(
 #' @name dbGetQuery
 #' @inheritParams DBI::dbGetQuery
 #' @param statistics If set to \code{TRUE} will print out AWS Athena statistics of query.
+#' @param unload boolean input to modify `statement` to align with \href{https://docs.aws.amazon.com/athena/latest/ug/unload.html}{AWS Athena UNLOAD},
+#'              default is set to \code{FALSE}.
 #' @return \code{dbGetQuery()} returns a dataframe.
 #' @seealso \code{\link[DBI]{dbGetQuery}}
 #' @examples
@@ -674,10 +693,12 @@ setMethod(
   "dbGetQuery", c("AthenaConnection", "character"),
   function(conn,
            statement = NULL, 
-           statistics = FALSE, ...){
+           statistics = FALSE,
+           unload = FALSE,
+           ...){
     con_error_msg(conn, msg = "Connection already closed.")
-    stopifnot(is.logical(statistics))
-    rs <- dbSendQuery(conn, statement = statement)
+    stopifnot(is.logical(statistics), is.logical(unload))
+    rs <- dbSendQuery(conn, statement = statement, unload = unload)
     if(statistics) print(dbStatistics(rs))
     out <- dbFetch(res = rs, n = -1, ...)
     dbClearResult(rs)
