@@ -101,27 +101,13 @@ LOCATION '",Sys.getenv("rathena_s3_tbl"),"test_df/default/'\n")))
 
 # static Athena Query Request Tests
 athena_test_req1 <-
-  list(QueryString = "select * from test_query",
-       QueryExecutionContext = list(Database = "default"),
-       ResultConfiguration = list(OutputLocation = Sys.getenv("rathena_s3_query"),
-                                  EncryptionConfiguration = list(EncryptionOption = "SSE_S3",
-                                                                 KmsKey = "test_key")),
-       WorkGroup = "test_group")
+  list(OutputLocation = Sys.getenv("rathena_s3_query"),
+       EncryptionConfiguration = list(EncryptionOption = "SSE_S3",
+                                      KmsKey = "test_key"))
 athena_test_req2 <-
-  list(QueryString = "select * from test_query",
-       QueryExecutionContext = list(Database = "default"),
-       ResultConfiguration = list(OutputLocation = Sys.getenv("rathena_s3_query"),
-                                  EncryptionConfiguration = list(EncryptionOption = "SSE_S3")),
-       WorkGroup = "test_group")
-athena_test_req3 <-
-  list(QueryString = "select * from test_query",
-       QueryExecutionContext = list(Database = "default"),
-       ResultConfiguration = list(OutputLocation = Sys.getenv("rathena_s3_query")),
-       WorkGroup = "test_group")
-athena_test_req4 <-
-  list(QueryString = "select * from test_query",
-       QueryExecutionContext = list(Database = "default"),
-       ResultConfiguration = list(OutputLocation = Sys.getenv("rathena_s3_query")),
-       WorkGroup = "primary")
+  list(OutputLocation = Sys.getenv("rathena_s3_query"),
+       EncryptionConfiguration = list(EncryptionOption = "SSE_S3"))
+athena_test_req3 <- list(OutputLocation = Sys.getenv("rathena_s3_query"))
+athena_test_req4 <- list(OutputLocation = Sys.getenv("rathena_s3_query"))
 
 show_ddl <- DBI::SQL(paste0('CREATE EXTERNAL TABLE `default.test_df`(\n  `w` timestamp, \n  `x` int, \n  `y` string, \n  `z` boolean)\nPARTITIONED BY ( \n  `timestamp` string)\nROW FORMAT DELIMITED \n  FIELDS TERMINATED BY \'\\t\' \n  LINES TERMINATED BY \'\\n\' \nSTORED AS INPUTFORMAT \n  \'org.apache.hadoop.mapred.TextInputFormat\' \nOUTPUTFORMAT \n  \'org.apache.hadoop.hive.ql.io.HiveIgnoreKeyTextOutputFormat\'\nLOCATION\n  \'' ,Sys.getenv("rathena_s3_tbl"), 'test_df/default\'\nTBLPROPERTIES (\n  \'skip.header.line.count\'=\'1\')'))
